summaryrefslogtreecommitdiffstats
path: root/snaps/openstack/utils/settings_utils.py
diff options
context:
space:
mode:
authorspisarski <s.pisarski@cablelabs.com>2017-11-16 16:07:47 -0700
committerspisarski <s.pisarski@cablelabs.com>2017-11-16 16:07:47 -0700
commit4cad4f7d1f53189900f9024fa5478e98a64d3760 (patch)
treea7a7161386d67b6a0214d7f802a5132b58ad2e71 /snaps/openstack/utils/settings_utils.py
parent792a01b6592b320b80bdc7465247b0fcb19f1264 (diff)
Refactoring of ImageSettings to extend ImageConfig
ImageSettings and glance_utils have a runtime cyclical dependency. This patch reduces this dependency and deprecates the ImageSettings class. JIRA: SNAPS-217 Change-Id: I09f34531366f2a5bd3202c9cbbdef878b2542abe Signed-off-by: spisarski <s.pisarski@cablelabs.com>
Diffstat (limited to 'snaps/openstack/utils/settings_utils.py')
-rw-r--r--snaps/openstack/utils/settings_utils.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/snaps/openstack/utils/settings_utils.py b/snaps/openstack/utils/settings_utils.py
index ea1d018..2560b21 100644
--- a/snaps/openstack/utils/settings_utils.py
+++ b/snaps/openstack/utils/settings_utils.py
@@ -348,14 +348,14 @@ def __create_floatingip_settings(neutron, port_settings):
return out
-def determine_image_settings(glance, server, image_settings):
+def determine_image_config(glance, server, image_settings):
"""
Returns a ImageSettings object from the list that matches the name in one
of the image_settings parameter
:param glance: the glance client
:param server: a SNAPS-OO VmInst domain object
:param image_settings: list of ImageSettings objects
:return: ImageSettings or None
"""
if image_settings:
for image_setting in image_settings:
@@ -348,14 +348,14 @@ def __create_floatingip_settings(neutron, port_settings):
"""
- Returns a ImageSettings object from the list that matches the name in one
+ Returns a ImageConfig object from the list that matches the name in one
of the image_settings parameter
:param glance: the glance client
@@ -348,14 +348,14 @@ def __create_floatingip_settings(neutron, port_settings):
:param glance: the glance client
:param server: a SNAPS-OO VmInst domain object
- :param image_settings: list of ImageSettings objects
- :return: ImageSettings or None
+ :param image_settings: list of ImageConfig objects
+ :return: ImageConfig or None
"""
if image_settings: